@@ -4,6 +4,7 @@ from pyspark.sql.types import StringType
 
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
 from spark_auto_mapper.data_types.coalesce import AutoMapperCoalesceDataType
+from spark_auto_mapper.data_types.datetime import AutoMapperDateTimeDataType
 from spark_auto_mapper.data_types.field import AutoMapperDataTypeField
 from spark_auto_mapper.data_types.filter import AutoMapperFilterDataType
 from spark_auto_mapper.data_types.hash import AutoMapperHashDataType
@@ -91,17 +92,36 @@ class AutoMapperHelpers:
         return AutoMapperDataTypeExpression(value)
 
     @staticmethod
-    def date(value: AutoMapperDateInputType) -> AutoMapperDateDataType:
+    def date(
+        value: AutoMapperDateInputType,
+        formats: Optional[List[str]] = None
+    ) -> AutoMapperDateDataType:
         """
-        Specifies that value should be parsed into a date.  We currently support the following formats:
-        yyyy-MM-dd
-        yyyyMMdd
-        MM/dd/yy
-        (For adding more, go to AutoMapperDateDataType)
-        :param value: text
-        :return: a date automapper type
+        Converts a value to date only
+        For datetime use the datetime mapper type
+
+
+        :param value: value
+        :param formats: (Optional) formats to use for trying to parse the value otherwise uses:
+                        y-M-d
+                        yyyyMMdd
+                        M/d/y
         """
-        return AutoMapperDateDataType(value)
+        return AutoMapperDateDataType(value, formats)
+
+    @staticmethod
+    def datetime(
+        value: AutoMapperDateInputType,
+        formats: Optional[List[str]] = None
+    ) -> AutoMapperDateTimeDataType:
+        """
+        Converts the value to a timestamp type in Spark
+
+
+        :param value: value
+        :param formats: (Optional) formats to use for trying to parse the value otherwise uses Spark defaults
+        """
+        return AutoMapperDateTimeDataType(value, formats)
 
     @staticmethod
     def amount(value: AutoMapperAmountInputType) -> AutoMapperAmountDataType:
@@ -135,7 +155,7 @@ class AutoMapperHelpers:
     @staticmethod
     def concat(
         *args: Union[AutoMapperNativeTextType, AutoMapperWrapperType,
-                     AutoMapperTextLikeBase]
+                     AutoMapperTextLikeBase, AutoMapperDataTypeBase]
     ) -> AutoMapperConcatDataType:
         """
         concatenates a list of values.  Each value can be a string or a column
@@ -500,3 +520,36 @@ class AutoMapperHelpers:
         return cast(
             'AutoMapperDataTypeBase', AutoMapperFloatDataType(value=value)
         )
+
+    @staticmethod
+    def flatten(
+        column: AutoMapperColumnOrColumnLikeType
+    ) -> "AutoMapperDataTypeBase":
+        """
+        creates a single array from an array of arrays.
+        If a structure of nested arrays is deeper than two levels, only one level of nesting is removed.
+        source: http://spark.apache.org/docs/latest/api/python/_modules/pyspark/sql/functions.html#flatten
+
+        :return: a flatten automapper type
+        """
+        from spark_auto_mapper.data_types.flatten import AutoMapperFlattenDataType
+
+        # cast it to the inner type so type checking is happy
+        return cast(
+            "AutoMapperDataTypeBase", AutoMapperFlattenDataType(column=column)
+        )
+
+    @staticmethod
+    def array(value: AutoMapperDataTypeBase) -> "AutoMapperDataTypeBase":
+        """
+        creates an array from a single item.
+        source: http://spark.apache.org/docs/latest/api/python/_modules/pyspark/sql/functions.html#array
+
+        :return: an array automapper type
+        """
+        from spark_auto_mapper.data_types.array import AutoMapperArrayDataType
+
+        # cast it to the inner type so type checking is happy
+        return cast(
+            "AutoMapperDataTypeBase", AutoMapperArrayDataType(value=value)
+        )
